@@ -27,6 +27,8 @@ def get_index(search_input, array_in):
     return return_idx
 
 
+# This function is to update the trial csv file by calling run_updater function
+# It has error handling in case of error
 def update_csv(input_csv_file_dir, extra_string_for_updated_csv, updater_config):
     success = True
     error_string = None
@@ -47,6 +49,7 @@ def update_csv(input_csv_file_dir, extra_string_for_updated_csv, updater_config)
     return trial_csv_file_name, output_dir_without_folder, success, error_string
 
 
+# This function is update the csv file according to the config input
 def run_updater(config, inputfile, outputfile, varargin=None):
     start_time = time.time()
     if varargin is not None:
@@ -119,7 +122,10 @@ def dispatch_function(this_filter, y, extra):
         n = this_filter["target_samplerate"]
         dT = np.nanmean(np.diff(t))
         T = 1 / dT
-        r = math.log(math.floor(T / n), 2)
+        try:
+            r = math.log(math.floor(T / n), 2)
+        except ValueError:
+            r = 0
 
         print('Target samplerate       = ', n)
         print('Estiametd samplerate    = ', T)
@@ -452,27 +458,7 @@ def get_timestamp_from_csv(csv_dir_input, column_name_input):
         return float(first_row[data_position])
 
 
-def get_eye_timestamp_info(gaze_dir_input):
-    info_dict = {}
-    with open(gaze_dir_input, "r") as csv_file:
-        csv_data = csv.reader(csv_file, delimiter=',')
-        header_array = next(csv_data)
-        event_string_position = get_position("event_string", header_array)
-        ts_position = get_position("sensor_timestamp", header_array)
-        for data in csv_data:
-            event_string = data[event_string_position]
-            if "start" in str(event_string):
-                trial_info = json.loads(event_string.replace("\'", "\""))
-                trial_id = trial_info["trial_id"] \
-                    if trial_info["trial_id"] != "undefined" else trial_info["trial_index"]
-                trial_type = trial_info["trial_type"]
-                timestamp_data = data[ts_position]
-                info_dict[trial_id] = {"trial_type": trial_type, "timestamp": timestamp_data}
-        csv_file.close()
-
-    return info_dict
-
-
+# This function is to start and end index of given trial in given gaze.csv file
 def get_start_end_info(csv_input, trial_id_input):
     start_index = None
     end_index = None
@@ -501,6 +487,7 @@ def get_start_end_info(csv_input, trial_id_input):
         return {"start_index": start_index, "end_index": end_index}
 
 
+# This function is replace incorrect data rows with correct data rows
 def replace_with_correct_data(trial_dir_input, gaze_dir_input, gaze_start_end_input):
     gaze_start_index = gaze_start_end_input["start_index"]
     gaze_end_index = gaze_start_end_input["end_index"]
@@ -565,6 +552,9 @@ def replace_with_correct_data(trial_dir_input, gaze_dir_input, gaze_start_end_in
         new_destination_file.close()
 
 
+# This function is the main function to correct trial data lost issue
+# by calling get_start_end_info and replace_with_correct_data
+# It also has error handling in case of error
 def fix_trial_data_lost(trial_dir_input, gaze_dir_input):
     success = True
     error_string = None
@@ -585,6 +575,7 @@ def fix_trial_data_lost(trial_dir_input, gaze_dir_input):
     return trial_csv_file_name, output_dir, success, error_string
 
 
+# This function is to get the build-in directory of config file by package name and config file name
 def get_config_location(package_name, config_file_name):
     config_dir = pkg_resources.resource_filename(package_name, config_file_name)
 
@@ -594,7 +585,7 @@ def get_config_location(package_name, config_file_name):
 def main():
     parser = argparse.ArgumentParser(prog='oknpatch',
                                      description='OKNPATCH package.')
-    parser.add_argument('--version', action='version', version='1.0.0'),
+    parser.add_argument('--version', action='version', version='1.0.1'),
     parser.add_argument("-t", dest="type_input", required=True, default=sys.stdin,
                         help="issue type to fix", metavar="issue type")
     parser.add_argument("-i", dest="first_input", required=False, default=sys.stdin,
